<?php
// This file is not called from WordPress. We don't like that.
! defined( 'ABSPATH' ) and exit;

/**
 * Theme config
 *
 * @author		wpthms
 * @copyright	Copyright ( c ) wpthms
 * @link		http://wpthms.com
 * @since		Version 1.0
 * @package 	Yeah Includes
 */
/**********************************************************************************************************
 * 
 * Do not edit this file.
 * To add custom PHP functions to the theme, create a new 'custom-functions.php' file in the theme folder.
 * 
***********************************************************************************************************/


/**
 * wpthms functions and definitions
 *
 * @package wpthms
 */

/**
 * Disable theme customizer
 *
 * @package wpthms
 */		
add_action( 'admin_bar_menu', 'yt_remove_some_nodes_from_admin_top_bar_menu', 999 );

function yt_remove_some_nodes_from_admin_top_bar_menu( $wp_admin_bar ) {
    $wp_admin_bar->remove_menu( 'customize' );
}

/*---------------------------------------------------------------------------------------------------------*
 * Setup
 *---------------------------------------------------------------------------------------------------------*/
add_action( 'after_setup_theme', 'yt_theme_setup', 1 );

if ( ! function_exists( 'yt_theme_setup' ) ) {
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
	function yt_theme_setup() {

		$yt_data = yt_get_options();
	
		/**
		 * Make theme available for translation
		 * Translations can be filed in the /languages/ directory
		 * If you're building a theme based on wpthms, use a find and replace
		 * to change 'wpthms' to the name of your theme in all the template files
		 */
		load_theme_textdomain( 'wpthms', get_template_directory() . '/languages' );
	
		/**
		 * Add default posts and comments RSS feed links to head
		 */
		add_theme_support( 'automatic-feed-links' );

		add_theme_support( 'title-tag' );
	
		/**
		 * Enable support for Post Thumbnails on posts and pages
		 *
		 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
		 */
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size( 710, 400 );


		/**
		 * This theme uses wp_nav_menu() in one location.
		 */
		register_nav_menus( array(
			'primary' => __( 'Main Menu', 'wpthms' ),
			'mobile' => __( 'Mobile Menu', 'wpthms' ),
			'top' => __( 'Top Menu', 'wpthms' ),
		) );
		/**
		 * Enable support for Post Formats
		 */
		add_theme_support( 'post-formats', array( 'image', 'gallery', 'audio', 'video', 'quote', 'link', ) );
	
		/**
		 * Setup the WordPress core custom background feature.
		 */
		
		add_filter( 'use_default_gallery_style', '__return_false' );

		add_filter( 'wp_page_menu_args', 'yt_page_menu_args' );

		add_filter( 'yt_pagination_nav_paginate_links_args', create_function( '$args', '$args["mid_size"] = 1; return $args;') );

		add_filter('yt_theme_meta_viewport_conditions', '__return_true' );

		add_filter( 'yt_admin_top_menu_bar_support_url', create_function( '', 'return "http://wpthms.com/support/forum/wordpress-themes-support-center/sparkle/";') );
		add_filter( 'yt_admin_top_menu_bar_document_url', create_function( '', 'return "http://docs.wpthms.com/sparkle/";') );


		add_filter( 'yt_support_theme_customizer', '__return_false' );

	}
}

function yt_jetpack_setup() {
	
	add_theme_support( 'infinite-scroll', array(
		'container' => 'content',
		'render'    => 'yt_infinite_scroll_render',
		'footer'    => false,
		'footer_callback'    => false,
		'wrapper' => false,
		'posts_per_page' => get_option('posts_per_page'),
	) );
} // end function yt_jetpack_setup
add_action( 'after_setup_theme', 'yt_jetpack_setup', 100 );

/**
 * Infinite scroll render function
 *
 * @since 2.0
 */
function yt_infinite_scroll_render() {
	$post_layout = yt_get_options( 'blog_post_layout' ); 
	$content_part = 'classic' == $post_layout ? '-classic' : '';

	yt_before_loop(); ?>

	<?php if ( have_posts() ) : ?>

		<?php /* Start the Loop */ 
		
		?>
		
		<?php while ( have_posts() ) : the_post(); ?>
		
			<?php yt_loop_start(); ?>
			
			<?php
				/* Include the Post-Format-specific template for the content.
				 * If you want to overload this in a child theme then include a file
				 * called content-___.php (where ___ is the Post Format name) and that will be used instead.
				 */

				get_template_part( "content{$content_part}", get_post_format() );
			?>
			
			<?php yt_loop_end(); ?>
			
		<?php endwhile; ?>

		<?php 
		if( 'number' == yt_get_options( 'blog_pagination' ) )
			yt_pagination_nav();
		else
			yt_direction_nav( 'nav-below' ); 
		?>

	<?php else : ?>

		<?php get_template_part( 'no-results', 'index' ); ?>

	<?php endif; ?>
	
	<?php yt_after_loop();
} // end function yt_infinite_scroll_render

/**
 * Change nonce life to 1 hour
 */
//add_filter('nonce_life', 'yt_change_nonce_hourly');
function yt_site_change_nonce_hourly( $nonce_life ) {
    return 60*60;
}
/**
 * Change the smallest size of default Tagcloud args
 *
 * @since 1.0
 */

add_filter( 'widget_tag_cloud_args', 'yt_site_widget_tag_cloud_args', 10, 2 );

if ( ! function_exists( 'yt_site_widget_tag_cloud_args' ) ) {
	function yt_site_widget_tag_cloud_args( $args ) {

		$args['smallest'] = 14;
		$args['largest'] = 28;
		$args['unit']    = 'px';

		return $args;  
	}

}

add_filter( 'infinite_scroll_archive_supported', 'yt_site_infinite_scroll_archive_supported', 19,1 );
/**
 * Infinite scroll supported archive
 *
 * @since 1.0
 */
function yt_site_infinite_scroll_archive_supported( $supported ) {

	global $wp_query;
	
	$supported = current_theme_supports( 'infinite-scroll' ) && ( ( $wp_query->is_home || $wp_query->is_search || $wp_query->is_archive ) && !yt_is_bbpress() && !yt_is_woocommerce() );

    return $supported;
}

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 */

if ( ! function_exists( 'yt_site_page_menu_args' ) ) {
	function yt_site_page_menu_args( $args ) {
		$args['show_home'] = true;
		return $args;
	}
}


/**
 * Adds custom classes to the array of body classes.
 *
 * @since 1.0
 */
add_filter( 'yt_frontend_body_class', 'yt_site_body_classes', 10 );

if ( ! function_exists( 'yt_site_body_classes' ) ) {
	function yt_site_body_classes( $classes ) {
		// Adds a class of group-blog to blogs with more than 1 published author
		if( 'hide' == yt_get_options('blog_post_format_icon') ){
			$classes[] = 'hide-post-format-icon';
		}
		if( yt_get_options( 'site_boxed_layout_mode' ) )
			$classes[] = 'boxed-layout';

		if( yt_get_options( 'site_width_large_mode' ) )
			$classes[] = 'large-display-layout';
		
		if( yt_get_options( 'header_scrollfix_mainmenu' ) )
			$classes[] = 'scroll-fix-header';

		if( 'modal' == yt_get_options( 'site_search_type' ) )
			$classes[] = 'modal-search';
		else
			$classes[] = 'default-search';

		global $post;

		$layout = yt_get_current_layout(yt_get_options( 'layout' ));
		
			$classes[] = "layout-$layout";


		if (is_singular('post') ) {
			foreach((get_the_category($post->ID)) as $category) {
				// add category slug to the $classes array
				$classes[] = "category-{$category->slug}";
			}
		}

		return $classes;
	}
}

/**
 * Replaces the excerpt "more" text by a link
 *
 * @since 1.0
 */
add_filter( 'the_content_more_link', 'yt_site_new_excerpt_more_content', 10 );

if ( ! function_exists( 'yt_site_new_excerpt_more_content' ) ) {
	function yt_site_new_excerpt_more_content($more) {
		
		return '';
	}
}

add_filter('excerpt_more', 'yt_site_new_excerpt_more');
if ( ! function_exists( 'yt_site_new_excerpt_more' ) ) {
	function yt_site_new_excerpt_more($more) {
		return '';
	}
}
add_filter( 'excerpt_length', 'yt_site_excerpt_length', 999 );
/**
 * Excerpt length
 *
 * @since 1.0
 */
if ( ! function_exists( 'yt_site_excerpt_length' ) ) {
	function yt_site_excerpt_length( $length ) {
		$length = yt_get_options( 'custom_excerpt_length' ) ? yt_get_options( 'custom_excerpt_length' ) : 30;
		return (int) $length;
	}
}

add_action( 'pre_get_posts', 'yt_site_pre_get_posts');
/**
 * Modify main query
 *
 * @since 1.0
 */
if ( ! function_exists( 'yt_site_pre_get_posts' ) ) {
	function yt_site_pre_get_posts($query){

		//////////////Exclude Categories
		$exclude_cats = yt_get_options( 'mainblog_exclude_cats' );
		
		//print_r($exclude_cats);
		//$exclude_cats = $exclude_cats ? join( ",", $exclude_cats ) : '';
		
		
		/*if(is_array($exclude_cats)){
			$exclude_cats_temp = array();
			foreach ( $exclude_cats as $cat) {
				if($cat)
					$exclude_cats_temp[] = '-'.$cat;
			}
			$exclude_cats = join( ",", $exclude_cats_temp );	
		}*/

		$exclude_cats = array_filter( ( array ) $exclude_cats );

		if( !empty( $exclude_cats  ) ){
			//array_walk( $exclude_cats , create_function('&$value, $key', '$value = "-$value";') );
			 
			//echo $exclude_cats;
			if ( $query->is_home && $query->is_main_query() ) {
				$query->set( 'category__not_in', $exclude_cats );
			}
		}

		//yt_pretty_print( $query ); die();
		
		if( $query->is_search ){
			 
		}
		
	}
}
add_action( 'yt_loop_start', 'yt_push_listed_posts_at_loop_start' );
/**
 * Filter posts
 *
 * @since 1.0.4.2
 */
function yt_push_listed_posts_at_loop_start(){
	YT_Post_Helpers::$listed_post[] = get_the_ID();
}

add_filter( 'infinite_scroll_js_settings', 'yt_site_infinite_scroll_js_settings');
/**
 * Infinite scroll settings
 *
 * @since 1.0
 */
if ( ! function_exists( 'yt_site_infinite_scroll_js_settings' ) ) {
	function yt_site_infinite_scroll_js_settings( $settings){
		$settings['text'] = __('Load more...', 'wpthms');
		return $settings;
	};
}
add_filter( 'yt_the_post_format_gallery_settings', 'yt_site_post_gallery_settings',10, 2 );
add_filter( 'yt_site_hero_banner_carousel_settings', 'yt_site_post_gallery_settings',10, 2 );
add_filter( 'yt_wp_default_gallery_settings', 'yt_site_post_gallery_settings',10, 2 );
add_filter( 'yt_theme_shortcode_slider_settings', 'yt_site_post_gallery_settings',10, 2 );
add_filter( 'yt_vc_carousel_settings', 'yt_site_post_gallery_settings',10, 2 );

/**
 * Add mor parameters yeah slider
 *
 * @since 1.0
 */
if ( ! function_exists( 'yt_site_post_gallery_settings' ) ) {
	function yt_site_post_gallery_settings( $settings, $type ) {
		$settings['prevText'] = sprintf( '<span class="nav-button"><i class="fa fa-chevron-left"></i> <span>%s</span>', __('Previous', 'wpthms') );
		$settings['nextText'] = sprintf( '<span class="nav-button"><i class="fa fa-chevron-right"></i> <span>%s</span></span>', __('Next', 'wpthms') );
		$settings['playText'] = sprintf( '<span class="nav-button"><i class="fa fa-play"></i> <span>%s</span></span>', __('Play', 'wpthms') );
		$settings['pauseText'] = sprintf( '<span class="nav-button"><i class="fa fa-pause"></i> <span>%s</span></span>', __('Pause', 'wpthms') );
		$settings['smoothHeight'] = true;
		
		// if( 'slider' == $type ){
		// 	$settings['css3Effect'] = 'flipIn';
		// 	$settings['animation'] = 'fade';
		// }
		return $settings;
	}
}
add_filter( 'yt_option_vars_footer_columns', 'yt_site_theme_options_vars_footer_columns' ); //Theme option footer columns
/**
 * Custom Footer Columns
 *
 * @since 1.0
 */
function yt_site_theme_options_vars_footer_columns( $columns ) {

	$url = wpthms_INCLUDES_URI . 'images/';

	$columns['yt-col-1-5_yt-col-1-5_yt-col-1-5_yt-col-1-5_yt-col-1-5'] 	= '1-5+1-5+1-5+1-5+1-5';
	$columns['yt-col-1-5_yt-col-1-5_yt-col-2-5_yt-col-1-5'] 			= '1-5+1-5+2-5+1-5';
	$columns['yt-col-1-5_yt-col-2-5_yt-col-1-5_yt-col-1-5'] 			= '1-5+2-5+1-5+1-5';
	$columns['yt-col-2-5_yt-col-1-5_yt-col-1-5_yt-col-1-5'] 			= '2-5+1-5+1-5+1-5';
	$columns['yt-col-1-5_yt-col-1-5_yt-col-1-5_yt-col-2-5'] 			= '1-5+1-5+1-5+2-5';
	$columns['yt-col-3-5_yt-col-1-5_yt-col-1-5'] 						= '3-5+1-5+1-5';
	$columns['yt-col-2-5_yt-col-2-5_yt-col-1-5'] 						= '2-5+2-5+1-5';
	$columns['yt-col-3-5_yt-col-2-5'] 									= '3-5+2-5';

	return $columns;
}
/*admin*/
if( is_admin() ):
/**
 * Init Category custom fields
 * Replaced in version 2.0
 */

/**
 * Register plugins
 */
include_once( get_template_directory() . '/framework/extended/class.tgm-plugin-activation.php');


add_action( 'tgmpa_register', 'yt_site_register_required_plugins' );


function yt_site_register_required_plugins(){

	if( !current_user_can( 'install_plugins' ) )
		return;
	/**
     * Array of plugin arrays. Required keys are name and slug.
     * If the source is NOT from the .org repo, then source is also required.
     */
    $plugins = array(

        array(
            'name'      => 'Contact Form 7',
            'slug'      => 'contact-form-7',
            'required'  => true,
        ),
        array(
            'name'      => 'bbPress',
            'slug'      => 'bbpress',
            'required'  => false,
        ),
        array(
            'name'      => 'Liveblog',
            'slug'      => 'liveblog',
            'required'  => false,
        ),
        array(
            'name'      => 'WooCommerce',
            'slug'      => 'woocommerce',
            'required'  => false,
        ),
        array(
            'name'      => 'WooCommerce Quantity Increment',
            'slug'      => 'woocommerce-quantity-increment',
            'required'  => false,
        ),
        array(
            'name'      => 'WP Review',
            'slug'      => 'wp-review',
            'required'  => false,
        ),
         array(
            'name'      => 'Widget Importer & Exporter',
            'slug'      => 'widget-importer-exporter',
            'required'  => false,
        ),
        array(
            'name'      => 'WordPress Importer',
            'slug'      => 'wordpress-importer',
            'required'  => false,
        ),
        array(
            'name'      => 'Regenerate Thumbnails',
            'slug'      => 'regenerate-thumbnails',
            'required'  => false,
        ),
        array(
            'name'      => 'Jetpack by WordPress.com',
            'slug'      => 'jetpack',
            'required'  => false,
        ),
        array(
            'name'      => 'WP Term Colors',
            'slug'      => 'wp-term-colors',
            'required'  => true,
        ),

        

    );

    /**
     * Array of configuration settings. Amend each line as needed.
     * If you want the default strings to be available under your own theme domain,
     * leave the strings uncommented.
     * Some of the strings are added into a sprintf, so see the comments at the
     * end of each line for what each argument will be.
     */
    $config = array(
        'id'           => 'tgmpa',                 // Unique ID for hashing notices for multiple instances of TGMPA.
        'default_path' => '',                      // Default absolute path to pre-packaged plugins.
        'menu'         => 'tgmpa-install-plugins', // Menu slug.
        'has_notices'  => true,                    // Show admin notices or not.
        'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
        'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
        'is_automatic' => false,                   // Automatically activate plugins after installation or not.
        'message'      => '',                      // Message to output right before the plugins table.
        'strings'      => array(
            'page_title'                      => __( 'Install Required Plugins', 'wpthms' ),
            'menu_title'                      => __( 'Install Plugins', 'wpthms' ),
            'installing'                      => __( 'Installing Plugin: %s', 'wpthms' ), // %s = plugin name.
            'oops'                            => __( 'Something went wrong with the plugin API.', 'wpthms' ),
            'notice_can_install_required'     => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.', 'wpthms' ), // %1$s = plugin name(s).
            'notice_can_install_recommended'  => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.', 'wpthms' ), // %1$s = plugin name(s).
            'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.', 'wpthms' ), // %1$s = plugin name(s).
            'notice_can_activate_required'    => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.', 'wpthms' ), // %1$s = plugin name(s).
            'notice_can_activate_recommended' => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.', 'wpthms' ), // %1$s = plugin name(s).
            'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.', 'wpthms' ), // %1$s = plugin name(s).
            'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.', 'wpthms' ), // %1$s = plugin name(s).
            'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.', 'wpthms' ), // %1$s = plugin name(s).
            'install_link'                    => _n_noop( 'Begin installing plugin', 'Begin installing plugins', 'wpthms' ),
            'activate_link'                   => _n_noop( 'Begin activating plugin', 'Begin activating plugins', 'wpthms' ),
            'return'                          => __( 'Return to Required Plugins Installer', 'wpthms' ),
            'plugin_activated'                => __( 'Plugin activated successfully.', 'wpthms' ),
            'complete'                        => __( 'All plugins installed and activated successfully. %s', 'wpthms' ), // %s = dashboard link.
            'nag_type'                        => 'updated' // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
        )
    );

    tgmpa( $plugins, $config );
}

/**
 * Ads Manager
 *
 * @since 1.0
 */

add_filter( 'yt_theme_options_advancedsettings_maintenance', 'yt_site_theme_options_ads_manager' );

function yt_site_theme_options_ads_manager( $options ){
	$options = array_merge( $options, apply_filters( 'yt_theme_options_ads_manager', array(
		array(
			'name' => __('Ads Manager','wpthms'),
			'type' => 'subheading',
			'customize' => 1,
			'customize_name' => __('Ads Manager','wpthms'),
			'settings' => array(
				'sanitize' => false
			),
		),
		array(
			'name' => '',
			'type' => 'info',
			'std' => '<h3>These Ad spaces support outputing shortcode and HTML content</h3><p>Recommended: Read the policies from Advertising Agency carefully before start using.<p>'
		),

		/*After header*/
		array( 
			'name' => __('After Header','wpthms'),
			'desc' => __('This ads will be displayed before header (site menu)<br>Add your Ads code or use the following custom html structure:','wpthms') . '<br>' . esc_attr( '<a href="#" target="_blank"><img src="http://placehold.it/728x90"></a>' ),
			'id' => 'site_ads_after_header',
			'std' => '<a href="#" target="_blank"><img src="http://placehold.it/728x90"></a>',
			'type' => 'textarea',
			'class' => 'yt-tabifiable-textarea',
			'customize' => 1,
			'settings' => array(
				'sanitize' => false
			),

		),
		/*Before footer*/
		array( 
			'name' => __('Before footer','wpthms'),
			'desc' => __('This ads will be displayed before footer widgets section','wpthms') . '<br>Add your Ads code or use the following custom html structure:' . esc_attr( '<a href="#" target="_blank"><img src="http://placehold.it/728x90"></a>' ),
			'id' => 'site_ads_before_footer',
			'std' => '<a href="#" target="_blank"><img src="http://placehold.it/728x90"></a>',
			'type' => 'textarea',
			'class' => 'yt-tabifiable-textarea',
			'customize' => 1,
			'settings' => array(
				'sanitize' => false
			),

		),

		/*Before single post*/
		array( 
			'name' => __('Before single post','wpthms'),
			'desc' => __('This ads will be displayed before single post content.<br>Add your Ads code or use the following custom html structure:','wpthms') . '<br>' . esc_attr( '<a href="#" target="_blank"><img src="http://placehold.it/300x250"></a>' ),
			'id' => 'site_ads_before_single_post',
			'std' => '<a href="#" target="_blank"><img src="http://placehold.it/300x250"></a>',
			'type' => 'textarea',
			'class' => 'yt-tabifiable-textarea',
			'customize' => 1,
			'settings' => array(
				'sanitize' => false
			),

		),
		/*Between single post*/
		array( 
			'name' => __('Between single post','wpthms'),
			'desc' => __('This ads will be displayed between single post content automatically (only apply to the post which have at least 2 paragraphs )<br>Add your Ads code or use the following custom html structure:','wpthms') . '<br>' . esc_attr( '<a href="#" target="_blank"><img src="http://placehold.it/300x250"></a>' ),
			'id' => 'site_ads_between_single_post',
			'std' => '<a href="#" target="_blank"><img src="http://placehold.it/300x250"></a>',
			'type' => 'textarea',
			'class' => 'yt-tabifiable-textarea',
			'customize' => 1,
			'settings' => array(
				'sanitize' => false
			),

		),

		/*After single post*/
		array( 
			'name' => __('After single post','wpthms'),
			'desc' => __('This will be displayed right below the single post content.<br>Add your Ads code or use the following custom html structure:','wpthms') . '<br>' . esc_attr( '<a href="#" target="_blank"><img src="http://placehold.it/728x90"></a>' ),
			'id' => 'site_ads_after_single_post',
			'std' => '<a href="#" target="_blank"><img src="http://placehold.it/728x90"></a>',
			'type' => 'textarea',
			'class' => 'yt-tabifiable-textarea',
			'customize' => 1,
			'settings' => array(
				'sanitize' => false
			),

		),

		/*After single post*/
		array( 
			'name' => __('Between Related posts and You might also like (single post)','wpthms'),
			'desc' => __('This will be displayed right below the single post content. after single post navigation, between Related Articles and You might also like section<br>Add your Ads code or use the following custom html structure:','wpthms') . '<br>' . esc_attr( '<a href="#" target="_blank"><img src="http://placehold.it/728x90"></a>' ),
			'id' => 'site_ads_between_rlpaymasl_single_post',
			'std' => '<a href="#" target="_blank"><img src="http://placehold.it/728x90"></a>',
			'type' => 'textarea',
			'class' => 'yt-tabifiable-textarea',
			'customize' => 1,
			'settings' => array(
				'sanitize' => false
			),

		)
	) ) );
	return $options;
}
/**
 * Misc
 *
 * @since 1.0.4
 */

add_filter( 'yt_theme_options_advancedsettings_miscs', 'yt_theme_options_advancedsettings_miscs_extras' );

function yt_theme_options_advancedsettings_miscs_extras( $options ){
	$new_setting = array( 
		array( 
			'name' => __('Overwrite default media gallery shortcode','wpthms'),
			'desc' => __('Notice: This option will overwrite all type of Jetpack Tiled Galleries under Gallery Settings and replace with Flexslider', 'wpthms'),
			'id' => 'allow_overwrite_default_gallery',
			'std' => 0,
			'type' => 'checkbox',
			'class' => 'yt-section-toggle-checkbox',
			'settings' => array(
				'label' => __('Switch this off if you want to replace default gallery with Flexslider','wpthms'),
				
			),				
		)
	);

	array_splice($options, 2, 0, $new_setting);

	return $options;
}

add_filter( 'yt_main_metabox_page_controls', 'yt_site_main_metabox_page_controls', 10 , 2 );

function yt_site_main_metabox_page_controls( $options, $shortname ){
	$framework_image_uri = wpthms_FRAMEWORK_URI . 'admin/assets/images/';
	$image_uri = wpthms_INCLUDES_URI . 'images/' ;
		
	$sidebar_list = yt_get_registered_sidebars();
	$sidebar_list['none'] = __( 'None', 'wpthms');

	$_show_hide = array(
		'show' => __( 'Show', 'wpthms'),
		'hide' => __( 'Hide', 'wpthms'),
	);

	$options = array_merge( $options, array(
		
		array( 
			'type' => 'tab',
			'name' => __( 'Hero Banner', 'wpthms'),
		),

		

			array( 
				'name' 		=> __( 'Hero Banner', 'wpthms' ),
				'desc'		=> '',
				'id' 		=> 'herobanner_mode',
				'std' 		=> sprintf( __('Since Sparkle v2, This section has been deprecated and moved to Theme Options -> Interface settings -> Hero Banner.<br>Please <a href="%s">click here</a> to reconfig Hero Banner.', 'wpthms'), esc_url( admin_url( 'admin.php?page=yt-theme-options#yt-option-herobanner-interfacesettings' ) ) ),
				'type' 		=> 'html'
			),
		
	));


	return $options;
}


add_filter( 'yt_main_metabox_page_settings', 'yt_site_main_metabox_page_settings', 10 , 2 ); //Page settings metabox
/**
 * Filter Main metabox tab: page settings
 *
 * @since 1.0
 */
if( !function_exists( 'yt_site_main_metabox_page_settings' ) ){
	function yt_site_main_metabox_page_settings( $settings, $shortname ) {

		$framework_image_uri = wpthms_FRAMEWORK_URI . 'admin/assets/images/';
		
		$sidebar_list = yt_get_registered_sidebars();
		$sidebar_list['none'] = __( 'None', 'wpthms');

		$_show_hide = array(
			'show' => __( 'Show', 'wpthms'),
			'hide' => __( 'Hide', 'wpthms'),
		);
		
		/*Tab: Page Settings */
		
		$settings = array(
			array( 
				'type' => 'tab',
				'name' => __( 'Page Settings', 'wpthms'),
			),
			array( 
				'name' 		=> __( 'Sidebar layout', 'wpthms' ),
				'desc' 		=> __( 'Default sidebar will be retrieved from Theme Options', 'wpthms' ),
				'id' 		=> $shortname . 'page_sidebar_layout',
				'std' 		=> 'default',
				'type' 		=> 'columns',
				'options' 	=> apply_filters( 'yt_main_metabox_page_settings_option_page_layout' ,array(
					'default' => 'default',
					'left-sidebar' => '4+8',
					'fullwidth' => '12',
					'right-sidebar' => '8+4',
					
				) )
				
			),
			array( 
				'name' 		=> __( 'Default sidebar', 'wpthms' ),
				'desc'		=> '',
				'id' 		=> $shortname . 'page_default_sidebar',
				'type' 		=> 'select',
				'std'		=> 'main-sidebar',
				'options'	=> $sidebar_list,
				'settings' => array()
			),
			array( 
				'name' 		=> __( 'Sub sidebar', 'wpthms' ),
				'desc'		=> '',
				'id' 		=> $shortname . 'page_sub_sidebar',
				'type' 		=> 'select',
				'std'		=> 'sub-sidebar',
				'options'	=> $sidebar_list,
				'settings' => array()
			),
			array( 
				'name' 		=> __( 'Page Title', 'wpthms' ),
				'desc'		=> '',
				'id' 		=> $shortname . 'page_title',
				'std' 		=> 'show',
				'type' 		=> 'toggles',
				'options'	=> $_show_hide
			),
			array( 
				'name' 		=> __( 'Page Content', 'wpthms' ),
				'desc'		=> '',
				'id' 		=> $shortname . 'page_content',
				'std' 		=> 'show',
				'type' 		=> 'toggles',
				'options'	=> $_show_hide
			),

		);
		
		return $settings;
		
	}
}

add_filter( 'yt_theme_options_option_general_site_layout', 'yt_site_supported_layout' ); // for theme options
add_filter( 'yt_main_metabox_page_settings_option_page_layout', 'yt_site_supported_layout' ); // for metabox
/**
 * Add more type of layout for theme options and metabox
 *
 * @since 1.0
 */
if( !function_exists( 'yt_site_supported_layout' ) ){
	function yt_site_supported_layout( $options){

		$include_image_uri = wpthms_INCLUDES_URI . 'images/' ;
		$options['double-sidebars'] = '6+3+3';
		return $options;
	}
}

endif; //is_admin




/*
 * WP-Review color
 *
 * @since 1.0.1
 * @framework 1.0
 */


add_filter( 'wp_review_default_colors', 'yt_site_wp_review_default_colors' );

if( function_exists( 'wp_review_render_meta_box_item')){

	function yt_site_wp_review_default_colors( $defaultColors ){

		$yt_data = yt_get_options();
		$primary_color = $yt_data['primary_color'] ? $yt_data['primary_color'] : ( $yt_data['builtin_skins'] ? $yt_data['builtin_skins'] : '#2cae8c');
		$primary_color = apply_filters( 'yt_site_styling_primary_color', $primary_color );

		$secondary_color = $yt_data['secondary_color'] ? $yt_data['secondary_color'] : '#363b3f';

		$defaultColors = array(
	    	'color' => $primary_color,
	    	'fontcolor' => '#7777777',
	    	'bgcolor1' => '#ffffff',
	    	'bgcolor2' => '#ffffff',
	    	'bordercolor' => '#eeeeee'
	    );

	    return $defaultColors;
	}
}

/*
 * Force Jetpack photon to crop various image sizes
 *
 * @since 1.0.4
 * @framework 1.0
 */

if( class_exists( 'Jetpack' ) ):

add_filter( 'jetpack_photon_image_downsize_array', 'yt_jetpack_photon_image_downsize_array', 10, 2 );

function yt_jetpack_photon_image_downsize_array( $photon_args, $args ){
	unset( $photon_args['fit'] );
	$photon_args['resize'] = $args['width'] . ',' .  $args['height'];
	return $photon_args;
}



add_filter( 'jetpack_photon_image_downsize_string', 'yt_jetpack_photon_image_downsize_string', 10, 2 );

function yt_jetpack_photon_image_downsize_string( $photon_args, $args ){
	if( !empty( $args['image_args']['width'] ) && !empty( $args['image_args']['height'] ) ){
		$photon_args['resize'] = $args['image_args']['width'] . ',' . $args['image_args']['height'];
		unset( $photon_args['fit'] );
	}
	
	return $photon_args;
}

endif; //end if Jetpack class

/*
 * Visual composer
 *
 * @since 1.0.4
 * @framework 1.0
 */
if( defined( 'WPB_VC_VERSION' ) ):

add_action( 'vc_before_init', 'yt_vc_vcSetAsTheme' );
function yt_vc_vcSetAsTheme() {
	vc_set_as_theme();
}
add_action( 'after_setup_theme', 'yt_vc_after_setup_theme' );

/*
 * Remove default elements
 *
 * @since 1.0.4
 */
function yt_vc_after_setup_theme(){

	/**********************************************************
	 * Locate Theme's vc templates
	 */
	if( function_exists( 'vc_set_shortcodes_templates_dir') && !apply_filters( 'yt_vc_disable_theme_templates', false ) ){
		$dir = wpthms_INCLUDES_DIR . '/vc-templates/';
		vc_set_shortcodes_templates_dir($dir);
	}
		
	/**********************************************************
	 * Disable Front-end Editor
	 */
	if( function_exists( 'vc_disable_frontend' ) && apply_filters( 'yt_vc_disable_frontend', true ) )
		vc_disable_frontend();

} 
add_filter('wpb_widget_title', 'yt_vc_override_widget_title', 10, 2);
// Filter to Replace default css class for vc_row shortcode and vc_column
function yt_vc_override_widget_title( $output = '', $params = array('')) {
	$extraclass = (!empty($params['extraclass'] ) ) ?  $params['extraclass'] : '';
	return '<h3' . ( $extraclass ? ' class="' . esc_attr( $extraclass ) . '"' : '' ) . '>' . $params['title'] . '</h3>';
}

endif;