<?php
// This file is not called from WordPress. We don't like that.
! defined( 'ABSPATH' ) and exit;

/**
 **********************************************************************************************************
 * 												DO NOT EDIT THIS FILE
 **********************************************************************************************************
 * Theme Styling
 *
 * @author		wpthms
 * @copyright	Copyright ( c ) wpthms
 * @link		http://wpthms.com
 * @since		Version 1.0
 * @package 	wpthms
 */

/**
 * Adjust a hex color brightness
 * Allows us to create hover styles for custom link colors
 * @param  strong $hex   hex color e.g. #111111
 * @param  integer $steps factor by which to brighten/darken ranging from -255 (darken) to 255 (brighten)
 * @return string        brightened/darkened hex color
 * @since  2.0.0
 */
function yt_adjust_color_brightness( $hex, $steps ) {
    // Steps should be between -255 and 255. Negative = darker, positive = lighter
    $steps  = max( -255, min( 255, $steps ) );

    // Format the hex color string
    $hex    = str_replace( '#', '', $hex );

    if ( 3 == strlen( $hex ) ) {
        $hex    = str_repeat( substr( $hex, 0, 1 ), 2 ) . str_repeat( substr( $hex, 1, 1 ), 2 ) . str_repeat( substr( $hex, 2, 1 ), 2 );
    }

    // Get decimal values
    $r  = hexdec( substr( $hex, 0, 2 ) );
    $g  = hexdec( substr( $hex, 2, 2 ) );
    $b  = hexdec( substr( $hex, 4, 2 ) );

    // Adjust number of steps and keep it inside 0 to 255
    $r  = max( 0, min( 255, $r + $steps ) );
    $g  = max( 0, min( 255, $g + $steps ) );
    $b  = max( 0, min( 255, $b + $steps ) );

    $r_hex  = str_pad( dechex( $r ), 2, '0', STR_PAD_LEFT );
    $g_hex  = str_pad( dechex( $g ), 2, '0', STR_PAD_LEFT );
    $b_hex  = str_pad( dechex( $b ), 2, '0', STR_PAD_LEFT );

    return '#' . $r_hex . $g_hex . $b_hex;
}
/** 
 * Theme Styling
 * Inline custom css
 * @since v2.0.0
 */
if( !function_exists( 'yt_site_css') ){
	function yt_site_css(){
		$data = yt_get_options();
		$primaryColor 	= $data['primary_color'] ? $data['primary_color'] : ( $data['builtin_skins'] ? $data['builtin_skins'] : '#2cae8c');
		$secondaryColor = $data['secondary_color'] ? $data['secondary_color'] : '#363b3f';
		$textColor 		= $data['text_color'] ? $data['text_color'] : '#777777';
		$whiteColor 	= '#ffffff';
		$baseFontSize 	= !empty( $data['typo_body_font']['size'] ) ? $data['typo_body_font']['size'] : '14px';
		if( 'color' == $data['header_color_style'] )
			$header_color_style = $primaryColor;
		elseif( 'dark' == $data['header_color_style'] )
			$header_color_style = $secondaryColor;
		elseif( 'light' == $data['header_color_style'] )
			$header_color_style = '#fff';
		else
			$header_color_style = '#000';

		$headerBgColor  				= !empty( $data['header_bg_options']['color'] ) ? $data['header_bg_options']['color'] : $header_color_style;
		$headerTopMenuLinkColor 		= 'light' == $data['header_color_style'] ? 'rgba(0,0,0,.7)' : 'rgba(255,255,255,.7)';
		$headerTopMenuLinkHoverColor 	= 'light' == $data['header_color_style'] ? $primaryColor : $whiteColor;
		// Allow modifying
		$vars = apply_filters('yt_site_less_css_variables', array(
			'siteMaxW'						=> $data['site_width'] ? intval( $data['site_width'] ) : 1370,	//Site wide
			'textColor' 					=> '#777777',
			'boldColor' 					=> '#333333',
			'grayColor' 					=> '#aaaaaa',
			'grayBgColor'					=> '#fafafa',
			'whiteColor'					=> '#ffffff',
			'blackColor'					=> '#000000',
			'borderOpacity' 				=> '0.08',
			'borderRadius' 					=> '2px',
			'baseFontSize'					=> !empty( $data['typo_body_font']['size'] ) ? $data['typo_body_font']['size'] : '14px',
			'iconFonts'						=> '"FontAwesome"',

			// =Colors
			'defaultColor'					=> '#fafafa',
			'primaryColor' 					=> $primaryColor,
			'secondaryColor' 				=> $secondaryColor,
			'successColor'        			=> '#5cb85c',
			'infoColor'            			=> '#5bc0de',
			'warningColor'         			=> '#f0ad4e',
			'dangerColor'          			=> '#d9534f',

			// =Body
			'bodyTextColor' 				=> '#777777',
			'linkColor' 					=> $primaryColor,
			'linkHoverColor' 				=> $secondaryColor,
			'boldTextColor' 				=> $secondaryColor,
			'grayBorderColor' 				=> '#eee',
			'grayBorderColorTransparent'	=> 'rgba(0,0,0,0.08)',

			// =Header
			'headerBgColor' 				=> $headerBgColor,
			'headerTopMenuBgColor' 			=> yt_adjust_color_brightness( $headerBgColor, -10 ),
			'headerTopMenuLinkColor' 		=> $headerTopMenuLinkColor,
			'headerTopMenuLinkHoverColor' 	=> $headerTopMenuLinkHoverColor,

			// =Mobile navigation
			'mobileMenuBgColor' 			=> $headerBgColor,
			'mobileMenuLinkColor' 			=> $headerTopMenuLinkColor,
			'mobileMenuLinkHoverColor' 		=> $headerTopMenuLinkHoverColor,

			// Menu
			'headerMenuLinkColor' 			=> 'light' == $data['header_color_style'] ? yt_adjust_color_brightness( $headerBgColor, -130 ) : yt_adjust_color_brightness( $headerBgColor, 130 ), 
			'headerMenuLinkHoverColor' 		=> $secondaryColor,
			'headerMenuLinkActiveColor' 	=> $secondaryColor,
			'headerMenuLinkActiveBgColor' 	=> $whiteColor,

			// Sub Menu
			'headerSubMenuLinkColor' 	 	=> $textColor,
			'headerSubMenuLinkHoverColor' 	=> $primaryColor,
			'headerSubMenuLinkActiveColor' 	=> $primaryColor,

			// =Content
			'contentLinkColor' 				=> $primaryColor,
			'contentLinkHoverColor'			=> $secondaryColor,
			'contentMenuLinkColor' 			=> $secondaryColor,
			'contentMenuLinkHoverColor'		=> $primaryColor,
			'contentMenuLinkActiveColor'	=> $primaryColor,
			'contentTextColor'				=> $textColor,

			// =Sidebar
			'sidebarTextColor' 				=> $textColor,
			'sidebarLinkColor' 				=> $primaryColor,
			'sidebarLinkHoverColor' 		=> $secondaryColor,
			'sidebarMenuLinkColor' 			=> $secondaryColor,
			'sidebarMenuLinkHoverColor' 	=> $primaryColor,
			'sidebarMenuLinkActiveColor' 	=> $primaryColor,

			// =Footer
			// Footer widgets
			'footerTextColor' 				=> $textColor,
			'footerLinkColor' 				=> $primaryColor,
			'footerLinkHoverColor' 			=> $secondaryColor,
			'footerMenuLinkColor' 			=> $textColor,
			'footerMenuLinkHoverColor' 		=> yt_adjust_color_brightness($textColor, -100 ),
			'footerMenuLinkActiveColor' 	=> $primaryColor,
		) );

		$css = "::selection {
			background-color: {$vars['primaryColor']};
			color: {$vars['whiteColor']};
		}
		::-moz-selection {
			background-color: {$vars['primaryColor']};
			color: {$vars['whiteColor']};
		}
		blockquote p{
			font-size: 18px;
		}
		.form-control,
		.btn,
		.navbar,
		.alert,
		.list-group {
			border-radius: {$vars['borderRadius']};
			-webkit-border-radius: {$vars['borderRadius']};
		}
		.form-control:focus {
			border-color: {$vars['primaryColor']};
			box-shadow: inset 0 1px 1px rgba(0,0,0,0.075), 0 0 8px {$vars['primaryColor']};
			-webkit-box-shadow: inset 0 1px 1px rgba(0,0,0,0.075), 0 0 8px {$vars['primaryColor']};
		}
		/**
		 * Button
		 */
		.btn-default,
		.btn-primary,
		.btn-secondary,
		.btn-success,
		.btn-info,
		.btn-warning,
		.btn-danger {
		    box-shadow: none !important;
		}


		/*Common styles*/
		.btn:active,
		.btn.active {
			background-image: none;
		}
		.btn i{
			color: {$vars['whiteColor']} !important;
		}
		.btn-link i,
		.btn-default i{
			color: {$vars['grayColor']} !important;
		}
		/*Apply the mixin to the buttons*/
		.btn:hover,
		.btn:focus,
		.btn:active,
		.btn.active {
			background-color: {$vars['secondaryColor']};
			border-color:{$vars['secondaryColor']};
			color: {$vars['whiteColor']} !important;
		}
		.btn-primary,
		.btn-secondary,
		.btn-success,
		.btn-info,
		.btn-warning,
		.btn-danger{
			color: {$vars['whiteColor']} !important;
		}
		/*Primary*/
		.btn-primary{
			background-repeat: repeat-x;
			background-color: {$vars['primaryColor']};
			border-color: {$vars['primaryColor']};
		}
		/*Secondary*/
		.btn-secondary{
			background-repeat: repeat-x;
			background-color: {$vars['secondaryColor']};
			border-color: {$vars['secondaryColor']};
		}
		/*Success*/
		.btn-success{
			background-color: {$vars['successColor']};
			border-color: {$vars['successColor']};
		}
		.btn-info{
			background-color: {$vars['infoColor']};
			border-color: {$vars['infoColor']};
		}
		.btn-warning{
			background-color: {$vars['warningColor']};
			border-color: {$vars['warningColor']};
		}
		.btn-danger{
			background-color: {$vars['dangerColor']};
			border-color: {$vars['dangerColor']};
		}
		.btn-link{	
			background: none;
			border-color: transparent;
		}
		.btn-link:hover{
			color: {$vars['secondaryColor']} !important;
		}
		/*Label*/

		.label-primary{
			background: {$vars['primaryColor']};
		}
		.label-success{
			background: {$vars['successColor']};
		}
		.label-info{
			background: {$vars['infoColor']};
		}
		.label-warning{
			background: {$vars['warningColor']};
		}
		.label-danger{
			background: {$vars['dangerColor']};
		}

		.form-group .control-label{
			color:{$vars['boldColor']};
		}
		/**
		 * Alert
		 */
		.alert {
			background-color: {$vars['grayBgColor']};
			border-color: #ddd;
			color:{$vars['textColor']};
		}

		.progress {				background-color:{$vars['grayBgColor']}; height: 24px;}
		.progress-bar {			background-color:{$vars['primaryColor']};text-align: left; text-indent: 1em; line-height: 24px;}
		.progress-bar-secondary {background-color:{$vars['secondaryColor']};}

		/**
		 * List group
		 */
		.panel-footer{
			background: {$vars['grayBgColor']};
			border-color: {$vars['grayBorderColor']};
			border-color: {$vars['grayBorderColorTransparent']};
		}
		.panel-default{
			border-color: {$vars['grayBorderColor']};
			border-color: {$vars['grayBorderColorTransparent']};
		}
		.panel-default > .panel-heading {
			background-color: {$vars['grayBgColor']};
			border-color: {$vars['grayBorderColor']};
			border-color: {$vars['grayBorderColorTransparent']};
		}
		.panel-primary{
			border-color:{$vars['primaryColor']};
		}
		.panel-primary > .panel-heading {
			background:{$vars['primaryColor']};
			border-color:{$vars['primaryColor']};

		}
		.panel-secondary{
			border-color:{$vars['secondaryColor']};
		}
		.panel-secondary > .panel-heading {
			background:{$vars['secondaryColor']};
			border-color:{$vars['secondaryColor']};
		}

		body{
			font-family:'Helvetica Neue', Helvetica, Arial, sans-serif;
			font-size: {$vars['baseFontSize']};
			line-height:1.75;
			color: {$vars['textColor']}; 
		}

		a{
			color: {$vars['linkColor']};
		}

		a:hover{
			color: {$vars['linkHoverColor']};
		}

		a.active, 
		.active a{
			color: {$vars['contentMenuLinkActiveColor']};
		}

		h1, h2, h3, h4, h5, h6,
		b, strong{
			color:  {$vars['secondaryColor']};
		}
		select:focus,
		select:active{
			border-color:  {$vars['primaryColor']};
			box-shadow: 0 0 5px  {$vars['primaryColor']};
		}
		input[type='text'], 
		input[type='number'], 
		input[type='email'], 
		input[type='url'], 
		input[type='password'], 
		input[type='search'], 
		textarea, textarea.form-control{
			line-height: 1.75;
		}
		input[type='text']:focus, 
		input[type='number']:focus, 
		input[type='email']:focus, 
		input[type='url']:focus, 
		input[type='password']:focus, 
		input[type='search']:focus, 
		textarea:focus, textarea.form-control:focus{
			border-color:  {$vars['primaryColor']};
			box-shadow: inset 0 1px 1px rgba(0,0,0,0.075), 0 0 8px {$vars['primaryColor']};
		}
		.boxed-layout #page{
			box-shadow: 0 0 30px rgba(0,0,0,0.2);
			-webkit-box-shadow: 0 0 30px rgba(0,0,0,0.2);
			-moz-box-shadow: 0 0 30px rgba(0,0,0,0.2);
		}
		/**
		 * Mejs audio Player
		 */
		#page .mejs-controls{
			background-color: {$vars['secondaryColor']};
		}
		#page .mejs-controls .mejs-time-rail .mejs-time-current,
		#page .mejs-controls .mejs-horizontal-volume-slider .mejs-horizontal-volume-current{
			background:  {$vars['primaryColor']};
		}
		#page .wp-playlist-light,
		#page .wp-playlist-item .wp-playlist-caption{
			color: {$vars['textColor']};
		}
		#page .wp-playlist-item.wp-playlist-playing .wp-playlist-caption{
			color: {$vars['primaryColor']};
		}

		/**
		 * =Mobile Menu
		 */
		.mobile-navigation{
			background-color: {$vars['mobileMenuBgColor']};
		}
		.mobile-navigation a{
			color: {$vars['mobileMenuLinkColor']};
		}
		.mobile-navigation a:hover{
			color: {$vars['mobileMenuLinkHoverColor']};
		}
				
		/**
		 * =Header
		 */   

		html .main-menu-toggle>*{
			background-color:{$vars['headerMenuLinkColor']} !important;
		}

		.site-header .site-top-menu{
			color: {$vars['headerTopMenuLinkColor']};
			background-color: {$vars['headerTopMenuBgColor']};
		}

		.site-header .site-top-menu li.current-menu-item > a{
			color: {$vars['headerTopMenuLinkHoverColor']};
		}
		.site-header .site-top-menu a{
			color: {$vars['headerTopMenuLinkColor']};
		}
		.site-header .site-top-menu a:hover{
			color: {$vars['headerTopMenuLinkHoverColor']};
		}
		.site-header .site-banner{
			background-color: {$vars['headerBgColor']};
		}
		/*Main nav*/
		.site-header .main-navigation .menu > li.menu-item:hover,
		.site-header .main-navigation .menu > li.current-menu-item{
			background-color:{$vars['headerMenuLinkActiveBgColor']};
		}
		.site-header .main-navigation .menu > li > a{
			color:{$vars['headerMenuLinkColor']};
		}
		.site-header .main-navigation .menu li.current > a{
			color: {$vars['primaryColor']};
		}
		.site-header .main-navigation .menu li.current-menu-item > a{
			color:{$vars['headerMenuLinkActiveColor']};
		}
		.site-header .main-navigation .menu li.menu-item:hover > a{
			color:{$vars['headerMenuLinkHoverColor']};
		}
		.site-header .main-navigation .menu ul li a{
			color: {$vars['headerSubMenuLinkColor']};
		}
		.site-header .main-navigation .menu ul li:hover > a,
		.site-header .main-navigation .menu ul li a:hover{
			color: {$vars['headerSubMenuLinkHoverColor']};
		}
		/**
		 * =Site hero
		 */
		.site-hero.style-color-gradient .hentry .hero-brick-bg:before {
		    background-repeat: repeat-x;
		    background-image: -webkit-linear-gradient(45deg,  {$vars['primaryColor']} 0%, rgba(111, 160, 33, 0) 100%);
		    background-image: linear-gradient(45deg,  {$vars['primaryColor']} 0%, rgba(111, 160, 33, 0) 100%);
		}

		/**
		 * =Sidebar
		 */

		.widget-area a{
			color: {$vars['sidebarLinkColor']};
		}
		.widget-area a:hover{
			color: {$vars['sidebarLinkHoverColor']};
		}
		.widget-area a.active,
		.widget-area .active > a{
			color: {$vars['sidebarMenuLinkActiveColor']};
		}
		.widget-area ul li.current-cat > a,
		.widget-area ul li.current_page_item > a{
			color: {$vars['sidebarMenuLinkActiveColor']};
		}
		.widget-area ul li a{
			color: {$vars['sidebarMenuLinkColor']};
		}
		.widget-area ul li a:hover{
			color: {$vars['sidebarMenuLinkHoverColor']};
		}

		/**
		 * =Footer
		 */
		.footer-widgets{
			color: {$vars['footerTextColor']};
		}
		.footer-widgets a{
			color: {$vars['footerLinkColor']};
		}
		.footer-widgets a:hover{
			color: {$vars['footerLinkHoverColor']};
		}
		.footer-widgets a.active, 
		.footer-widgets .active > a{
			color: {$vars['footerMenuLinkActiveColor']};
		}

		.footer-widgets ul li.current-cat a,
		.footer-widgets ul li.current_page_item a{
			color: {$vars['footerMenuLinkActiveColor']};
		}
		.footer-widgets ul li a{
			color: {$vars['footerMenuLinkColor']};
		}
		.footer-widgets ul li a:hover{
			color: {$vars['footerMenuLinkHoverColor']};
		}
		/**
		 * Cat tag
		 */
		.cat-tag{
			color:{$vars['whiteColor']};
			background-color: {$vars['primaryColor']};
			opacity: .95;
		}
		/**
		 * Entry tag
		 */
		.entry-tags a{
			color:{$vars['textColor']};
		}
		.entry-tags a:hover{
			color:{$vars['whiteColor']};

		}
		/**
		 * Color
		 */
		 .site-banner .site-logo a,
		 .main-navigation ul.menu>li.site-mobile-menu-toggle{
		 	color: {$vars['headerMenuLinkColor']};
		 }
		/**
		 * Primary color
		 */
		.primary-color,
		.primary-2-secondary a,
		.secondary-2-primary a:hover,
		.secondary-2-primary a:hover > *,
		.gray-2-primary:hover,
		.gray-2-primary a:hover,
		.gray-2-primary a:hover *,
		.current-cat a,
		.current_page_item a,
		.pagination-nav .page-numbers.current{
			color: {$vars['primaryColor']};
		}
		/**
		 * Secondary color
		 */
		.secondary-color,
		.secondary-2-primary a,
		.primary-2-secondary a:hover,
		.primary-2-secondary a:hover *,
		.gray-2-secondary:hover,
		.gray-2-secondary a:hover,
		.gray-2-secondary a:hover *,
		.form-allowed-tags code,
		.pagination-nav a.page-numbers:hover,
		.yeahslider.news-scroller a.yeahslider-next:hover, 
		.yeahslider.news-scroller a.yeahslider-prev:hover{
			color: {$vars['secondaryColor']};
		}
		/**
		 * Gray color
		 */
		.gray-color,
		.gray-2-secondary a,
		.gray-2-primary,
		.gray-2-primary a,
		.gray-icon,
		.gray-icon i,
		time,
		.pagination-nav a.page-numbers,
		.yt-social-sharing span.show-all-social-services i,
		.yeahslider.news-scroller a.yeahslider-next, 
		.yeahslider.news-scroller a.yeahslider-prev{
			color: {$vars['grayColor']};
		}

		/**
		 * Background
		 */
		.white-bgcolor,
		.boxed-layout .inner-wrapper{
			background-color:{$vars['whiteColor']};
		}
		.yt-social-sharing span.show-all-social-services,
		.entry-tags a{
			background-color: {$vars['grayBgColor']};
		}

		.secondary-bgcolor,
		.site-modal .site-modal-backdrop,
		.yeahslider .slides li .caption,
		.yeahslider .yeahslider-direction-nav a > span.nav-button, 
		.yeahslider .yeahslider-pauseplay a > span.nav-button{
			background-color: {$vars['secondaryColor']};
		}
		.primary-bgcolor,
		.entry-tags a:hover{
			background-color: {$vars['primaryColor']};
		}
		.review-mark.review-type-percentage,
		.review-mark.review-type-point{
			background: {$vars['primaryColor']};
		}
		/**
		 * Border Color
		 */
		.yt-sliding-tabs-header-trigger > span:before{
			border-color: {$vars['whiteColor']};
		}
		fieldset legend,
		.wp-caption:before,
		.boundary-column:before,
		.site-content[role='main'] article.post,
		#page .wp-playlist.wp-audio-playlist,
		.widget:before,
		.yt-twitter-profile-wrapper .yt-twitter-profile-body,
		.yt-tabby-tabs-header,
		.slashes-navigation li:before,
		.pagination-nav .page-numbers:before,
		.yt-sliding-tabs-header-trigger > span,
		.post-list-with-thumbnail.vertical li:before,
		.post-list-with-thumbnail li a span.number:before,
		.post-page-navigation,
		.post-page-navigation:before,
		.comments-area,
		.comment-body,
		.yt-font-size-changer span,
		.yt-impressive-like-button .yt-il-symbol, 
		.yt-impressive-like-button .yt-il-symbol > span,
		.infinite-scroll #infinite-handle span{
			border-color: {$vars['grayBorderColor']};
			border-color: {$vars['grayBorderColorTransparent']};
		}";

		/*Theme Options styles*/
		$css .= !empty( $data['custom_css'] ) ? $data['custom_css'] : '';
		$css .= yt_get_theme_customfonts();
		$css .= 'h1{'. yt_output_option( 'typography', $data['typo_h1'] ) . '}
		h2{' . yt_output_option( 'typography', $data['typo_h2'] ) . '}
		h3, .widget-title{' . yt_output_option( 'typography', $data['typo_h3'] ) . '}
		h4{' . yt_output_option( 'typography', $data['typo_h4'] ) . '}
		h5{' . yt_output_option( 'typography', $data['typo_h5'] ) . '}
		h6{' . yt_output_option( 'typography', $data['typo_h6'] ) . '}
		h1 strong, h2 strong, h3 strong, h4 strong, h5 strong, h6 strong{' . yt_output_option( 'typography', $data['typo_bold_heading'] ) . '}';

		// Body
		$css .= 'body{';
			$css .= "color:$textColor;";
			$css .= yt_output_option( 'typography', $data['typo_body_font'] );			
			if($data['body_bg_pattern_mode'] && $data['body_bg_pattern'] )
				$data['body_bg_options']['image'] = $data['body_bg_pattern'];
			$css .= yt_output_option( 'background_options', $data['body_bg_options'] )  . "\n" ;
		$css .= '}' . "\n";

		// #page
		$css .= '.inner-wrapper{';
			if($data['content_bg_pattern_mode'] && $data['content_bg_pattern'] )
				$data['content_bg_options']['image'] = $data['content_bg_pattern'];
			$css .= yt_output_option( 'background_options', $data['content_bg_options'] )  . "\n" ;
		$css .= '}' . "\n";

		$css .= '.site-header .site-banner{';
			if($data['header_bg_pattern_mode'] && $data['header_bg_pattern'] )
				$data['header_bg_options']['image'] = $data['header_bg_pattern'];
			$css .= yt_output_option( 'background_options', $data['header_bg_options'] )  . "\n" ;
		$css .= '}';

		$css .= '
		.site-header .main-navigation ul.menu > li > a, .site-mobile-navigation ul.menu > li {' . yt_output_option( 'typography', $data['typo_top_menu'] ) . '}
		.site-header ul ul.sub-menu > li, .site-mobile-navigation ul ul.sub-menu > li{' . yt_output_option( 'typography', $data['typo_top_menu_child'] ) . '}
		.site-content article .entry-title{' . yt_output_option( 'typography', $data['typo_entry_title'] ) . '}
		h1.page-title, h1.entry-title, .site-content article h1.entry-title{' . yt_output_option( 'typography', $data['typo_page_title'] ) . '}
		.widget-title{' . yt_output_option( 'typography', $data['typo_sidebar_widget_headings'] ) . '}
		#site-hero h2.entry-title{' . yt_output_option( 'typography', $data['typo_home_brick_entry_title'] ) .'}';

		/*Background style*/
		$css .= '.footer-widgets{' . "\n";
			if($data['footer_widgets_bg_pattern_mode'] && $data['footer_widgets_bg_pattern'] )
				$data['footer_widgets_bg_options']['image'] = $data['footer_widgets_bg_pattern'];
			$css .= yt_output_option( 'background_options', $data['footer_widgets_bg_options'] )  . "\n" ;
			$css .= yt_output_option( 'typography', $data['typo_footer_element'] ). "\n";
		$css .= '}' . "\n";

		$css .= '.footer-widgets h1, .footer-widgets h2, .footer-widgets h3, .footer-widgets h4, .footer-widgets h5, .footer-widgets h6{' . yt_output_option( 'typography', $data['typo_footer_headings'] ) . '}' . "\n";
		$css .= $data['footer_extra_bg_color'] ? '.site-footer .footer-info{ background-color:' . $data['footer_extra_bg_color'] . ';}' : '';

		/**
		 * Category color
		 */
		// Get from cache
		$cat_colors = get_transient( 'category_meta_colors' );

		if( false === $cat_colors ){
			$c_terms = get_terms( 'category', array( 'hide_empty' => 0 ) );
			
			if( !empty( $c_terms ) ){
				foreach ($c_terms as $term) {

					// Get color from meta
					if( function_exists( 'get_term_meta' ) && ( $color = get_term_meta( $term->term_id, 'color', true ) ) ){
						$cat_colors[$term->slug] = $color;

					// get accent color from old key
					}elseif( ( $cat_meta = get_option( "category_{$term->term_id}" ) ) && !empty( $cat_meta['color'] ) ){
						$cat_colors[$term->slug] = $cat_meta['color'];

						// migrate to term meta and delete old option.
						if( function_exists( 'function_exists') ){
							update_term_meta( $term->term_id, 'color', $cat_meta['color'] );
							delete_option( "category_{$term->term_id}" );
						}
					}
					
					
				}
				// Cache category colors
				set_transient( 'category_meta_colors', $cat_colors );
			}
		}


		if( !empty( $cat_colors ) ){

			foreach ( $cat_colors as $cat_id => $cat_color ) {
				$css .= $cat_color ? "\t.cat-tag.{$cat_id}{ background-color:{$cat_color};}\n" : "";
				$css .= $cat_color ? "\t.category-meta .{$cat_id}{ color:{$cat_color};}\n" : "";
				
				$css .= $cat_color ? "\t.site-hero.style-color-gradient .hentry.category-{$cat_id} .hero-brick-bg:before{
					 background-repeat: repeat-x;
				    background-image: -webkit-linear-gradient(45deg,  {$cat_color} 0%, rgba(111, 160, 33, 0) 100%);
				    background-image: linear-gradient(45deg,  {$cat_color} 0%, rgba(111, 160, 33, 0) 100%);
					
				}\n" : "";
			}
		}

		$siteWideWrapper = ( int ) $vars['siteMaxW'] + 30;
		/**
		 * Large Screen
		 */
		if( $data['site_width_large_mode'] ){
			$css .= "@media (min-width: {$siteWideWrapper}px){
				.boxed-layout.large-display-layout #page, 
				.boxed-layout.large-display-layout .site-banner{
					width: {$siteWideWrapper}px;
				}
				.container {
					width: {$vars['siteMaxW']}px;
				}
				.site-hero .hero-brick .entry-header .entry-title{
					font-size: 24px;
				}
				.site-hero .hero-brick-large .entry-header .entry-title{
					font-size: 48px;
					line-height: 1.25;
				}
				.site-hero .posted-on,
				.site-hero .entry-category{
					display:inline-block;
				}
			}";
		} 
		
		// Inline css :P
		$css = str_replace(array("\r", "\n", "\t"), "", $css);

		echo sprintf('<style id="custom-styles">%s</style>', $css );

	}
}

add_action( 'wp_head', 'yt_site_css' );

/*
 * Dynamically genetate css using less css with pre-defined styles + theme options data
 *
 * {$vars['@since 1.']}0
 * @return string
 */
if( !function_exists( 'yt_site_get_dynamic_css') ) {

	function yt_site_get_dynamic_css(){
	}
		
}
/*
 * Remove transients after updating theme options
 *
 * @since 2.0
 * @return string
 */
function yt_theme_delete_transients_when_edited_category(){
	delete_transient( 'category_meta_colors' );
}

add_action( 'created_category', 'yt_theme_delete_transients_when_edited_category' );
add_action( 'edited_category', 'yt_theme_delete_transients_when_edited_category' );